/* 
 * The MIT License
 * 
 * Copyright (c) 2007 University of Salzburg, www.uni-salzburg.at
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package at.uni_salzburg.cs.exotasks.editor.timing.htl;

import java.util.ArrayList;

import org.eclipse.jface.viewers.IStructuredContentProvider;
import org.eclipse.jface.viewers.Viewer;

import at.uni_salzburg.cs.exotasks.timing.htl.HTLProgram;
import at.uni_salzburg.cs.exotasks.timing.htl.HTLProgramList;

/**
 * @author Daniel Iercan (diercan@aut.upt.ro)
 *
 **/
public class HTLProgramListContentProvider implements
		IStructuredContentProvider {

	/** Number of blank rows to show in the table */
	  private static final int MIN_ROWS = 30;
	  
	  // @see org.eclipse.jface.viewers.IContentProvider#dispose()
	  public void dispose()
	  {
	  }

	  // @see org.eclipse.jface.viewers.IContentProvider#inputChanged(org.eclipse.jface.viewers.Viewer, java.lang.Object, java.lang.Object)
	  public void inputChanged(Viewer viewer, Object oldInput, Object newInput)
	  {
	  }

	  // @see org.eclipse.jface.viewers.IStructuredContentProvider#getElements(java.lang.Object)
	  public Object[] getElements(Object inputElement)
	  {
	    HTLProgramList programList = (HTLProgramList) inputElement;
	    if (programList == null) {
	      return new String[0][1];
	    }
	    
	    ArrayList programs = programList.getPrograms();
	    int numRows = programs.size();
	    if (numRows < MIN_ROWS) {
	      numRows = MIN_ROWS;
	    }
	    String[][] ans = new String[numRows][];
	    for (int i = 0; i < programs.size(); i++) {
	      HTLProgram program = (HTLProgram)programs.get(i);
	      ans[i] = new String[] {program.getName()};
	    }
	    for (int i = programs.size(); i < ans.length; i++) {
	      ans[i] = new String[] {""};
	    }
	    return ans;
	  }

}
