/* 
 * The MIT License
 * 
 * Copyright (c) 2007 University of Salzburg, www.uni-salzburg.at
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package at.uni_salzburg.cs.exotasks.scheduling.ecode;

import at.uni_salzburg.cs.exotasks.scheduling.ITaskCompletionCallback;
import at.uni_salzburg.cs.exotasks.scheduling.ecode.ECodeRunner.TriggerElement;
import at.uni_salzburg.cs.exotasks.scheduling.utils.DoubleLinkedList;



/**
 * The callback function used to update the trigger queue.
 * @author Daniel Iercan (diercan@aut.upt.ro)
 *
 */
public class TaskCompletionCallback implements ITaskCompletionCallback{
	private DoubleLinkedList rqueue;
	
	public TaskCompletionCallback(DoubleLinkedList rqueue){
		this.rqueue = rqueue;
	}
	
	public synchronized void taskCompleted(int pTaskIndex) {
		for(TriggerElement trigger = (TriggerElement) rqueue.getHead();
    	  trigger != null;
    	  trigger = (TriggerElement) rqueue.getNext(trigger)) {
		  trigger.dependencyList &= (~ (1l << pTaskIndex));			
		}
		try{
        	synchronized(rqueue){
        		rqueue.notifyAll();
        	}
    	}
    	catch(Exception e){
    		e.printStackTrace();
    	}
	}
}